@@ -1,12 +1,11 @@
 package DBIx::Class::InflateColumn::Crypt::Passphrase;
-$DBIx::Class::InflateColumn::Crypt::Passphrase::VERSION = '0.002';
+$DBIx::Class::InflateColumn::Crypt::Passphrase::VERSION = '0.003';
 use strict;
 use warnings;
 
 use parent 'DBIx::Class';
 
-use Crypt::Passphrase 0.006;
-use Crypt::Passphrase::PassphraseHash;
+use Crypt::Passphrase 0.007;
 use Scalar::Util 'blessed';
 
 use namespace::clean;
@@ -21,7 +20,7 @@ sub register_column {
 
 	$self->inflate_column(
 		$column => {
-			inflate => sub { Crypt::Passphrase::PassphraseHash->new($crypt_passphrase, shift) },
+			inflate => sub { $crypt_passphrase->curry_with_hash(shift) },
 			deflate => sub { shift->raw_hash },
 		},
 	);
@@ -43,7 +42,7 @@ DBIx::Class::InflateColumn::Crypt::Passphrase - Inflate/deflate columns to passp
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
